% script that illustrates Kalman filter on a simple model;

close all 
clear all
clc

%% Set filtration range
rng_filt = qq(2010,1):qq(2016,4);

% range for reporting
rng_report = qq(2009,1):qq(2016,4);

%% load and solve the model

% read model quations from the file, create their representation in Matlab
m = Model.fromFile('closed_model.model','linear',true);

% assign numerical values to model parameters
p = setparam;
m = assign(m,p);

% find the model solution
m = solve(m);

% find model steady-state (equlibrium)
m = steady(m); 

%

%% Baseline

% Create empty database of observables
dbobs = steadydb(m,qq(2010,1):qq(2012,4));
% assign one observation of inflation
dbobs.obs_dl_cpi(qq(2013,1)) = 4; 

% Run Kalman Filter
db_filt = kalmanFilter(m,dbobs,rng_filt);

%% Report results of the baseline
b = db_filt.Mean;   

% make a picture showing the IRFs
figure('Name','Baseline Kalman filter results');

subplot(231);
plot(b.l_y_gap,'lineWidth',3);
grid;
title('Output gap (%)');

subplot(232);
plot(b.dl_cpi,'lineWidth',3);
grid;
title('Inflation (%)');

subplot(233);
plot(b.r_gap,'lineWidth',3);
grid;
title('RIR Gap (%)');

subplot(234);
plot(b.shock_l_y_gap,'lineWidth',3);
grid;
title('Output Gap Shock');

subplot(235);
plot(b.shock_dl_cpi,'lineWidth',3);
grid;
title('Inflation Shock');

subplot(236);
plot(b.shock_r_gap,'lineWidth',3);
grid;
title('RIR Gap Shock');

%% Alternative - more volatile demand shock

% set up the same observations as in the baseline
dbobs = steadydb(m,qq(2010,1):qq(2012,4));
dbobs.obs_dl_cpi(qq(2013,1)) = 4;

% Create "double" model
m2 = alter(m,2);

% Change std of demand shock - the second model will have higher std
m2.std_shock_l_y_gap = [1 3];
m2 = solve(m2);
m2 = steady(m2);

% Run Kalman Filter
db_filt = kalmanFilter(m2,dbobs,rng_filt);

%% Report results

b = db_filt.Mean;   

% make a picture showing the IRFs
figure('Name','Alternative Kalman filter results');

subplot(231);
plot(b.l_y_gap,'lineWidth',3);
grid;
title('Output gap (%)');

subplot(232);
plot(b.dl_cpi,'lineWidth',3);
grid;
title('Inflation (%)');

subplot(233);
plot(b.r_gap,'lineWidth',3);
grid;
title('RIR Gap (%)');

subplot(234);
plot(b.shock_l_y_gap,'lineWidth',3);
grid;
title('Output Gap Shock');

subplot(235);
plot(b.shock_dl_cpi,'lineWidth',3);
grid;
title('Inflation Shock');

subplot(236);
plot(b.shock_r_gap,'lineWidth',3);
grid;
title('RIR Gap Shock');
