% script that illustrates Kalman filter on a simple model;

% close all 
clear all
close all
clc

%% load and solve the model

% read model quations from the file, create their representation in Matlab
m = Model.fromFile('closed_model.model','linear',true);

% assign numerical values to model parameters
p = setparam;
m = assign(m,p);

% find the model solution
m = solve(m);

% find model steady-state (equlibrium)
m = steady(m); 

%% Create multiple parameterizations if needed
% % Create "double" model - one Matlab object which contains two copies of
% the original model
% m = alter(m,2);
% 
% % Assign two different values to the same parameter in model 1 and model
% 2
% m.c1_l_y_gap = [0.55 0.75];
% 
% % Solve both models and find their steady-state
% m = solve(m);
% m = steady(m); 
% 
% ss = get(m,'steady')

%% Run the IRFs

% run a loop over model shocks
shocks = get(m,'elist');

for iShock = 1:numel(shocks)
  % iterate over shocks

  % Create initial condition
  dbinit = zerodb(m,qq(2010,1):qq(2012,4));

  % find the name of this shock
  shk = shocks{iShock};
  
  % set the shock to non-zero value in the first period of simulation
  dbinit.(shk)(qq(2013,1)) = 1;
  
  % run the simulation
  s = simulate(m,dbinit,qq(2013,1):qq(2018,1),'deviation',true);
  s = dboverlay(s, dbinit);
  
  % make a picture showing the IRFs
  figure('Name',['IRF to ' shk]);

  subplot(221);
  plot(s.l_y_gap,'lineWidth',3);
  grid;
  title('Output gap (%)');

  subplot(222);
  plot(s.dl_cpi,'lineWidth',3);
  grid;
  title('Inflation (%)');

  subplot(223);
  plot(s.r_gap,'lineWidth',3);
  grid;
  title('Real interest rate gap (pp)'); 
end
